@@ -159,9 +159,9 @@ def style_transfer(
     
     assert get_bit_depth(original_audio_file_path) == 16, "The bit depth of the original audio file %s must be 16" % original_audio_file_path
     
-    if(duration > 20):
-        print("Warning: The duration of the audio file %s must be less than 20 seconds. Longer duration will result in Nan in model output (we are still debugging that); Automatically set duration to 20 seconds")
-        duration = 20
+    # if(duration > 20):
+    #     print("Warning: The duration of the audio file %s must be less than 20 seconds. Longer duration will result in Nan in model output (we are still debugging that); Automatically set duration to 20 seconds")
+    #     duration = 20
     
     if(duration >= audio_file_duration):
         print("Warning: Duration you specified %s-seconds must equal or smaller than the audio file duration %ss" % (duration, audio_file_duration))
@@ -200,7 +200,8 @@ def style_transfer(
     init_latent = latent_diffusion.get_first_stage_encoding(
         latent_diffusion.encode_first_stage(mel)
     )  # move to latent space, encode and sample
-
+    if(torch.max(torch.abs(init_latent)) > 1e2):
+        init_latent = torch.clip(init_latent, min=-10, max=10)
     sampler = DDIMSampler(latent_diffusion)
     sampler.make_schedule(ddim_num_steps=ddim_steps, ddim_eta=1.0, verbose=False)
 
@@ -217,11 +218,9 @@ def style_transfer(
                     )
 
                 c = latent_diffusion.get_learned_conditioning([prompts] * batchsize)
-
                 z_enc = sampler.stochastic_encode(
                     init_latent, torch.tensor([t_enc] * batchsize).to(device)
                 )
-
                 samples = sampler.decode(
                     z_enc,
                     c,
@@ -229,8 +228,12 @@ def style_transfer(
                     unconditional_guidance_scale=guidance_scale,
                     unconditional_conditioning=uc,
                 )
-
+                # x_samples = latent_diffusion.decode_first_stage(samples) # Will result in Nan in output
+                # print(torch.sum(torch.isnan(samples)))
                 x_samples = latent_diffusion.decode_first_stage(samples)
+                # print(x_samples)
+                x_samples = latent_diffusion.decode_first_stage(samples[:,:,:-3,:])
+                # print(x_samples)
                 waveform = latent_diffusion.first_stage_model.decode_to_waveform(
                     x_samples
                 )
